@@ -76,6 +76,8 @@ def parse_bandwidth_metrics(powermetrics_parse):
 
 
 def parse_cpu_metrics(powermetrics_parse):
+    e_core = []
+    p_core = []
     cpu_metrics = powermetrics_parse["processor"]
     cpu_metric_dict = {}
     # cpu_clusters
@@ -84,6 +86,17 @@ def parse_cpu_metrics(powermetrics_parse):
         name = cluster["name"]
         cpu_metric_dict[name+"_freq_Mhz"] = int(cluster["freq_hz"]/(1e6))
         cpu_metric_dict[name+"_active"] = int((1 - cluster["idle_ratio"])*100)
+        for cpu in cluster["cpus"]:
+            name = 'E-Cluster' if name[0] == 'E' else 'P-Cluster'
+            core = e_core if name[0] == 'E' else p_core
+            core.append(cpu["cpu"])
+            cpu_metric_dict[name + str(cpu["cpu"]) + "_freq_Mhz"] = int(cpu["freq_hz"] / (1e6))
+            try:
+                cpu_metric_dict[name + str(cpu["cpu"]) + "_active"] = int((1 - cpu["idle_ratio"]) * 100)
+            except:
+                cpu_metric_dict[name + str(cpu["cpu"]) + "_active"] = int(100)
+    cpu_metric_dict["e_core"] = e_core
+    cpu_metric_dict["p_core"] = p_core
     if "E-Cluster_active" not in cpu_metric_dict:
         # M1 Ultra
         cpu_metric_dict["E-Cluster_active"] = int(
@@ -114,10 +127,10 @@ def parse_cpu_metrics(powermetrics_parse):
                 cpu_metric_dict["P0-Cluster_freq_Mhz"], cpu_metric_dict["P1-Cluster_freq_Mhz"])
     # power
     cpu_metric_dict["ane_W"] = cpu_metrics["ane_energy"]/1000
-    cpu_metric_dict["dram_W"] = cpu_metrics["dram_energy"]/1000
+    #cpu_metric_dict["dram_W"] = cpu_metrics["dram_energy"]/1000
     cpu_metric_dict["cpu_W"] = cpu_metrics["cpu_energy"]/1000
     cpu_metric_dict["gpu_W"] = cpu_metrics["gpu_energy"]/1000
-    cpu_metric_dict["package_W"] = cpu_metrics["package_energy"]/1000
+    cpu_metric_dict["package_W"] = cpu_metrics["combined_power"]/1000
     return cpu_metric_dict
 
 
